@@ -5,7 +5,7 @@ provide basic methods to query any modem.
 """
 
 import logging
-from abc import ABC   # , abstractmethod
+from abc import ABC
 from typing import Optional, Union
 
 from pyatcommand import AtClient, xmodem_bytes_handler
@@ -15,6 +15,7 @@ from .common import (
     ModemModel,
     NetworkProtocol,
     NetworkState,
+    NetInfo,
     SignalQuality,
     PowerMode,
     WakeupInterval,
@@ -40,6 +41,9 @@ class SatelliteModem(AtClient, ABC):
         self._firmware_version: str = ''
         self._command_timeout = 1
     
+    def _post_mutate(self) -> None:
+        """Run after mutating the base class to apply __init__ settings."""
+    
     def connect(self, **kwargs) -> None:
         super().connect(**kwargs)
         self._autoconfig = False   # avoid potential false V0/E0 detection
@@ -83,8 +87,10 @@ class SatelliteModem(AtClient, ABC):
                                 raise ValueError('Unsupported protocol value')
             elif 'QUECTEL' in mfr_res.info.upper():
                 model = ModemModel.CC200A
-        if model != self._model:
+        if self._model != ModemModel.UNKNOWN and model != self._model:
             _log.warning('Detected %s but expected %s', model.name, self.model)
+        elif model == ModemModel.UNKNOWN:
+            _log.warning('Unable to determine modem model')
         return model
         
     @property
@@ -120,7 +126,7 @@ class SatelliteModem(AtClient, ABC):
         raise NotImplementedError('Implement in model-specific subclass')
     
     # @abstractmethod
-    def get_netinfo(self):
+    def get_netinfo(self) -> NetInfo:
         """Get details of the acquisition process."""
         raise NotImplementedError('Implement in model-specific subclass')
     
@@ -321,8 +327,8 @@ class SatelliteModem(AtClient, ABC):
         Args:
             **stale_secs (int): The maximum age of the fix to return.
             **wait_secs (int): The maximum time to wait for a fix.
-            **nmea_sentences (str): A CSV list of valid sentence types including
-                RMC,GGA,GSA,GSV.
+            **nmea_sentences (str): A CSV list of valid sentence types.
+                May include RMC,GGA,GSA,GSV.
                 
         Returns:
             GnssLocation or None if a GNSS timeout occurs.
